@@ -3,7 +3,7 @@
   -------------------
   A brewing recipe calculator for Unix/X11
   -------------------
-  Copyright 1999-2002, David Johnson
+  Copyright 1999-2004, David Johnson
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -17,10 +17,6 @@
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
 
-  3. Neither the name of the author nor the names of the contributors
-     may be used to endorse or promote products derived from this
-     software without specific prior written permission.
-
   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
@@ -38,22 +34,13 @@
 #include <iostream>
 
 #include <qapplication.h>
-#include <qdir.h>
 #include <qstring.h>
 
-#include "calc.h"
 #include "controller.h"
-#include "model.h"
-#include "preferences.h"
 #include "resource.h"
 
 using namespace std;
 using namespace AppResource;
-using namespace CalcResource;
-
-// TODO: put in Qt options in dohelp()
-// TODO: implement session management
-// TODO: splash screen ?
 
 //////////////////////////////////////////////////////////////////////////////
 // doversion()
@@ -89,11 +76,6 @@ void dohelp()
     // misc options
     cout << "Miscellaneous Options\n\n";
     cout << "    These are options for the Qt library and the X Windows System.\n";
-    cout << "-style=style\n";
-    cout << "    Sets the application GUI style. Possible values are cde, motif,\n";
-    cout << "    motifplus, platinum, sgi and windows. Note that this option has\n";
-    cout << "    no effect if a style other than 'default' was selected in the\n";
-    cout << "    options menu\n";
     cout << "-display display\n";
     cout << "    Sets the X display (default is $DISPLAY).\n";
     cout << "-geometry geometry\n";
@@ -107,19 +89,10 @@ void dohelp()
     cout << "    Sets the default foreground color.\n";
     cout << "-btn or -button color\n";
     cout << "    Sets the default button color.\n";
-    cout << "-visual TrueColor\n";
-    cout << "    Forces the application to use a TrueColor visual on an 8-bit\n";
-    cout << "    display.\n";
-    cout << "-cmap\n";
-    cout << "    Causes the application to install a private color map on an 8-bit\n";
-    cout << "    display.\n";
-    cout << "-name name\n";
-    cout << "    Sets the application name.\n";
     cout << endl;
 
     // bug reports
     cout << "Report bugs to <" << PACKAGE_BUGREPORT << ">" << endl;
-
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -135,16 +108,16 @@ QString doargs(int argc, char **argv)
         if ((arg.lower() == "-h") || (arg == "-help") ||
             (arg == "--help") || (arg == "-?")) {
             dohelp();
-            exit(0);
+            return QString::null;
         } else if ((arg.lower() == "-v") || (arg == "-version") ||
                    (arg == "--version")) {
             doversion();
-            exit(0);
+            return QString::null;
         } else if (arg[0] == '-') {
             // no other valid options
             cout << "Invalid parameter \"" << arg << "\"\n";
             dohelp();
-            exit(1);
+            return QString::null;
         } else {
             // must be a filename
             return arg;
@@ -158,22 +131,17 @@ QString doargs(int argc, char **argv)
 // ------
 // Entry point of application
 
-// TODO: figure out executable path under win32
-// From the command line I will have full path in argv[0], but launched
-// from the GUI I am relying on currentDirPath(), which is not good...
-// need something like [QFileInfo( qtapp->argv()[0] ).absFilePath()]
-
 int main(int argc, char ** argv)
 {
     QApplication app(argc, argv);
 
     // check for additional command line options before we go further
     QString filename = doargs(app.argc(), app.argv());
+    if (filename.isEmpty()) return 0;
 
     Controller* controller = Controller::instance();
     controller->initialize(filename);
     app.setMainWidget(controller);
-    controller->setCaption(AppResource::ID_TITLE + " " +  VERSION);
 
     controller->show();
     QObject::connect(qApp, SIGNAL(lastWindowClosed()), qApp, SLOT(quit()));
