@@ -3,10 +3,7 @@
   -------------------
   Model class for brewing
   -------------------
-  begin         12/12/2001
-  author        David Johnson <david@usermode.org>
-  -------------------
-  Copyright (c) 2002 David Johnson
+  Copyright (c) 2001-2004 David Johnson
   Please see the header file for copyright and license information.
  ***************************************************************************/
 
@@ -18,7 +15,6 @@
 
 #include "controller.h"
 #include "resource.h"
-#include "resource.h"
 
 #include "model.h"
 
@@ -29,26 +25,14 @@ Model *Model::instance_ = 0;
 
 // Construction, Destruction /////////////////////////////////////////////////
 
-// Private constructor.
+// Private constructor
 Model::Model()
-    : groupmap_(), fieldmap_(), defaultsize_(Volume(5.0, Volume::gallon)),
+    : QObject(0, "model"), defaultsize_(Volume(5.0, Volume::gallon)),
+      defaultmash_(false), defaulthopform_(HOP_PELLET),
       defaultgrainunit_(&Weight::pound), defaulthopsunit_(&Weight::ounce),
       defaultmiscunit_(&Quantity::generic), graindb_(), hopdb_(), miscdb_(),
       styledb_(), recipe_(0), datadir_("")
 {
-    // set up group map
-    groupmap_[groupRecipe] = gidRecipe;
-    groupmap_[groupDocGrains] = gidDocGrains;
-    groupmap_[groupDocHops] = gidDocHops;
-    groupmap_[groupDocMisc] = gidDocMisc;
-
-    // set up recipe attributes
-    fieldmap_[fieldTitle] = fidTitle;
-    fieldmap_[fieldBrewer] = fidBrewer;
-    fieldmap_[fieldStyle] = fidStyle;
-    fieldmap_[fieldSize] = fidSize;
-    fieldmap_[fieldMash] = fidMash;
-
     // load data file - try user home directory first, quietly...
     if (!loadData(QDIR_HOME + "/." + ID_CALC_FILE, true)) {
         // then the default data file
@@ -65,12 +49,11 @@ Model::Model()
     recipe_ = new Recipe();
 }
 
-// Private destructor.
+// Private destructor
 Model::~Model()
-{
-}
+{ ; }
 
-// Return pointer to the model.
+// Return pointer to the model
 Model *Model::instance()
 {
     if (!instance_)
@@ -100,7 +83,7 @@ void Model::setDefaultGrainUnit(Unit &u)
     defaultgrainunit_ = &u;
     // convert recipe grain units
     GrainIterator it;
-    for (it = recipe_->grains()->begin(); it != recipe_->grains()->end(); ++it )
+    for (it = recipe_->grains()->begin(); it != recipe_->grains()->end(); ++it)
         (*it).weight().convert(u);    
     // convert graindb units
     for (it = graindb_.begin(); it != graindb_.end(); ++it )
@@ -112,7 +95,7 @@ void Model::setDefaultHopsUnit(Unit &u)
     defaulthopsunit_ = &u;
     // convert recipe hop units
     HopIterator it;
-    for (it = recipe_->hops()->begin(); it != recipe_->hops()->end(); ++it )
+    for (it = recipe_->hops()->begin(); it != recipe_->hops()->end(); ++it)
         (*it).weight().convert(u);
     // convert hopsdb units
     for (it = hopdb_.begin(); it != hopdb_.end(); ++it )
@@ -124,7 +107,7 @@ void Model::setDefaultMiscUnit(Unit &u)
     defaultmiscunit_ = &u;
     // convert recipe misc units
     MiscIngredientIterator it;
-    for (it = recipe_->miscs()->begin(); it != recipe_->miscs()->end(); ++it )
+    for (it = recipe_->miscs()->begin(); it != recipe_->miscs()->end(); ++it)
         (*it).quantity().convert(u);
     // convert miscdb units
     for (it = miscdb_.begin(); it != miscdb_.end(); ++it )
@@ -249,12 +232,12 @@ QStringList Model::hopsList()
 QStringList Model::formsList()
 {
     QStringList list;
-    list += HOP_PELLET;
-    list += HOP_PLUG;
-    list += HOP_WHOLE;
+    list << HOP_PELLET << HOP_PLUG << HOP_WHOLE;
+    // search through existing hopdb for other forms
     HopIterator it;
     for (it=hopdb_.begin(); it!=hopdb_.end(); ++it) {
-        if (list.contains((*it).form()) == 0) list += (*it).form();
+        if ((!(*it).form().isEmpty())
+            && (list.contains((*it).form()) == 0)) list += (*it).form();
     }
     list.sort();
     return list;
@@ -369,7 +352,7 @@ bool Model::loadData(const QString &filename, bool quiet)
     QDomNodeList subnodes;
     QDomElement element;
     QDomElement subelement;
-	unsigned n, m;
+    unsigned n, m;
     for (n=0; n<nodes.count(); ++n) {
         if (nodes.item(n).isElement()) {
             element = nodes.item(n).toElement();
@@ -423,7 +406,7 @@ bool Model::loadData(const QString &filename, bool quiet)
                 if (subnodes.item(m).isElement()) {
                     subelement = subnodes.item(m).toElement();
                     hopdb_.append(Hops(subelement.text(),
-                        Weight(1.0, *defaulthopsunit_), HOP_PELLET,
+                        Weight(1.0, *defaulthopsunit_), QString::null,
                         subelement.attribute(attrAlpha).toDouble(), 60));
                 }
             }
@@ -576,8 +559,11 @@ void Model::saveData(const QString &filename)
 void Model::newRecipe()
 {
     if (recipe_) delete recipe_;
-    recipe_ = new Recipe("", "", false, defaultsize_, defaultstyle_,
-                         GrainList(), HopsList(), MiscIngredientList(), "", "");
+    recipe_ = new Recipe(QString::null, QString::null, defaultmash_,
+                         defaultsize_, defaultstyle_, GrainList(), HopsList(),
+                         MiscIngredientList(), QString::null, QString::null);
+    setModified(false);
+    emit (recipeChanged());
 }
 
 //////////////////////////////////////////////////////////////////////////////
@@ -756,6 +742,7 @@ bool Model::loadRecipe(const QString &filename)
     Calc::recalc(recipe_);
     // just loaded recipes are not modified
     setModified(false);
+    emit (recipeChanged());
     return true;
 }
 
@@ -930,17 +917,22 @@ QString Model::recipeText()
         buffer += (*itm).quantity().toQString() + ", ";
         buffer += (*itm).notes() + '\n';
     }
-    
+
+    // TODO: long notes don't wrap...
     buffer += "Recipe Notes:\n" + recipe_->recipeNotes() + "\n\n";
-    buffer += "Batch Notes:\n" + recipe_->recipeNotes() + "\n\n";
+    buffer += "Batch Notes:\n" + recipe_->batchNotes() + "\n\n";
 
     buffer += ID_TITLE + " " + VERSION;
     return buffer;
 }
 
-/*
-Local variables:
-mode: c++
-c-basic-offset: 4
-End:
-*/
+///////////////////////////////////////////////////////////////////////////////
+// Miscellaneous                                                             //
+///////////////////////////////////////////////////////////////////////////////
+
+void Model::setModified(bool mod)
+{
+    recipe_->setModified(mod);
+    if (mod) emit recipeModified();
+}
+
