@@ -12,10 +12,7 @@
         </group>
     </preferences>
   -------------------
-  begin         Tue Sep 12 2000
-  author        David Johnson, david@usermode.org
-  -------------------
-  Copyright 2000, David Johnson
+  Copyright 2000-2004, David Johnson
   Please see the header file for copyright and license information
 ***************************************************************************/
 
@@ -234,8 +231,8 @@ void Preferences::readData()
     // open file
     QFile* datafile = new QFile(file_);
     if (!datafile->open(IO_ReadOnly)) {
-        // error opening file
-        qWarning("Error: cannot open preferences file " + file_);
+        // warning opening file (this isn't an error)
+        qWarning("Warning: cannot open preferences file " + file_);
         datafile->close();
         delete (datafile);
         filestate_ = false;
